from flask import Flask, jsonify, render_template
from celery.app.control import Inspect

from auto_transcoder.model import MediaDAO, RedisManager
from auto_transcoder.tasks import celery_app as celery_app

def run(redis_manager: RedisManager, *args, **kwargs):
    app = Flask(__name__)

    @app.route('/')
    def index():
        return render_template('index.html')

    @app.route('/api/workers')
    def queues():
        i = inspect()
        workers = i.stats()
        return jsonify(workers)
    
    @app.route('/api/inodes')
    async def inodes():
        return await MediaDAO(redis_manager=redis_manager).get_all_inodes()
    
    app.run(*args, **kwargs)

def inspect() -> Inspect:
    return celery_app.control.inspect()
